@@ -19,11 +19,12 @@
 #ifndef KFINDDLG_H
 #define KFINDDLG_H
 
-#include <kdialog.h>
-#include <kdirlister.h>
-#include <kdirwatch.h>
+#include <QDialog>
+#include <QLabel>
+#include <QtGlobal>
 
-#include <qglobal.h>
+#include <KDirLister>
+#include <KDirWatch>
 
 QT_FORWARD_DECLARE_CLASS(QDir)
 QT_FORWARD_DECLARE_CLASS(QString)
@@ -33,9 +34,11 @@ class KQuery;
 class KFileItem;
 class KfindTabWidget;
 class KFindTreeView;
-class KStatusBar;
+class QLabel;
+class QPushButton;
+class QStatusBar;
 
-class KfindDlg : public KDialog
+class KfindDlg : public QDialog
 {
     Q_OBJECT
 
@@ -72,10 +75,15 @@ Q_SIGNALS:
 private:
     KfindTabWidget *tabWidget;
     KFindTreeView *win;
+    QPushButton *m_saveAsButton;
+    QPushButton *m_stopButton;
+    QPushButton *m_findButton;
+    QStatusBar *mStatusBar;
+    QLabel *m_labelStatus;
+    QLabel *m_labelProgress;
 
     bool isResultReported;
     KQuery *query;
-    KStatusBar *mStatusBar;
     KDirLister *dirlister;
     KDirWatch *dirwatch;
 };
